Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5024)

Unified Diff: chrome/browser/installable/installable_manager.h

Issue 2611623003: Use exact pixel sizes instead of dip in webapp/WebAPK installability code (Closed)
Patch Set: Rebased version of pkotwicz@'s original patch Created 3 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/banners/app_banner_manager.cc ('k') | chrome/browser/installable/installable_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/installable/installable_manager.h
diff --git a/chrome/browser/installable/installable_manager.h b/chrome/browser/installable/installable_manager.h
index 92ac41eb5d66afa7e45beab6257fd72bae7dc22a..5dbd659be39bc1b4e2a7949840f77d0969a20d50 100644
--- a/chrome/browser/installable/installable_manager.h
+++ b/chrome/browser/installable/installable_manager.h
@@ -26,10 +26,10 @@
// manifest will always be fetched first.
struct InstallableParams {
// The ideal icon size to fetch. Used only if |fetch_valid_icon| is true.
- int ideal_icon_size_in_dp = -1;
+ int ideal_icon_size_in_px = -1;
// The minimum icon size to fetch. Used only if |fetch_valid_icon| is true.
- int minimum_icon_size_in_dp = -1;
+ int minimum_icon_size_in_px = -1;
// Check whether the site is installable. That is, it has a manifest valid for
// a web app and a service worker controlling the manifest start URL and the
@@ -82,7 +82,7 @@ class InstallableManager
~InstallableManager() override;
// Returns the minimum icon size in pixels for a site to be installable.
// TODO(dominickn): consolidate this concept with minimum_icon_size_in_dp
// across all platforms.
static int GetMinimumIconSizeInPx();
« no previous file with comments | « chrome/browser/banners/app_banner_manager.cc ('k') | chrome/browser/installable/installable_manager.cc » ('j') | no next file with comments »
@@ -82,7 +82,7 @@ class InstallableManager
~InstallableManager() override;
// Returns the minimum icon size in pixels for a site to be installable.
- // TODO(dominickn): consolidate this concept with minimum_icon_size_in_dp
+ // TODO(dominickn): consolidate this concept with minimum_icon_size_in_px
// across all platforms.
static int GetMinimumIconSizeInPx();

Powered by Google App Engine
This is Rietveld 408576698